@@ -6,18 +6,26 @@ using namespace Rcpp;
 using namespace arma;
 
 
-arma::vec QRWMR(arma::mat const &x, arma::vec const &y, arma::vec b)
+arma::vec QRWMR(arma::mat const &x, arma::vec const &y, arma::vec b, bool debugging)
 {
   int p = x.n_cols, n = x.n_rows;
   arma::vec t = y - x * b;
   arma::vec u(n, fill::none), w(n, fill::none);
   arma::uvec index;
-  
+
   for(int m = 0; m < p; m++){
     t += x.col(m) * b(m);
     u = t/x.col(m);
     w = arma::abs(x.col(m))/n;
-    
+
+    u.elem(arma::find(x.col(m) == 0)).fill(0);
+
+    if (debugging) {
+      // Rcpp::Rcout << "Values of u before NaN replacement for column " << m << ":\n";
+      // u.print(Rcpp::Rcout);
+      u.replace(datum::nan, 0);
+    }
+
     index = arma::sort_index(u);
     // arma::vec _w = w(index), _u = u(index);
 
@@ -35,17 +43,25 @@ arma::vec QRWMR(arma::mat const &x, arma::vec const &y, arma::vec b)
   return(b);
 }
 
-void QRWMR(arma::mat const &x, arma::vec const &y, arma::vec &b, arma::mat const &w, arma::vec const &totalWeights)
+void QRWMR(arma::mat const &x, arma::vec const &y, arma::vec &b, arma::mat const &w, arma::vec const &totalWeights, bool debugging)
 {
   int p = x.n_cols, n = x.n_rows;
   arma::vec t = y - x * b;
   arma::vec u(n, fill::none);
   arma::uvec index;
-  
+
   for(int m = 0; m < p; m++){
     t += x.col(m) * b(m);
     u = t/x.col(m);
 
+    u.elem(arma::find(x.col(m) == 0)).fill(0);
+
+    if (debugging) {
+      // Rcpp::Rcout << "Values of u before NaN replacement for column " << m << ":\n";
+      // u.print(Rcpp::Rcout);
+      u.replace(datum::nan, 0);
+    }
+
     index = arma::sort_index(u);
 
 	double SUM = 0;
